import React, { useEffect, useRef } from "react";
import * as d3 from 'd3';

const Bar = ({ data, width, height }: any) => {
    const svgRef: any = useRef<SVGSVGElement>(null);

    useEffect(() => {
        const margin = { top: 10, right: 10, bottom: 20, left: 40 };
        console.log(data)

        const svg = d3
            .select(svgRef.current);

        const everything = svg.selectAll("*");
        everything.remove();

        const xScale: any = d3
            .scaleBand()
            .domain(data.map((d: any) => d.date))
            .range([0, width - margin.left - margin.right]);

        const X = d3
            .axisBottom(xScale);

        svg
            .append('g')
            .attr('class', 'x-axis')
            .attr('transform', `translate(0, ${height - margin.top - margin.bottom})`)
            .call(X);

        const yDomain: any[] = [0, d3.max(data, (d: any) => d.numberSales)];
        const yScale: any = d3
            .scaleLinear()
            .domain(yDomain)
            .range([height - margin.top - margin.bottom, 0])
            .nice();

        const Y = d3
            .axisLeft(yScale)
            .ticks(6)
            .tickSize(-(width - margin.left - margin.right));

        svg
            .append('g')
            .attr('class', 'y-axis')
            .call(Y);

        const colorScale = d3.scaleOrdinal(d3.schemePaired);

        svg
            .selectAll('.bar')
            .data(data)
            .enter()
            .append('rect')
            .attr('class', 'bar')
            .attr('x', (d: any) => xScale(d.date))
            .attr('y', (d: any) => yScale(d.numberSales))
            .attr('height', (d: any) => (height - margin.top - margin.bottom - yScale(d.numberSales)))
            .attr('width', _ => xScale.bandwidth())
            .style('fill', (d: any, i: any) => colorScale(i));

        svg
            .selectAll('.bar-label')
            .data(data)
            .enter()
            .append('text')
            .classed('bar-label', true)
            .attr('x', (d: any) => xScale(d.date) + xScale.bandwidth() / 2)
            .attr('dx', 0)
            .attr('y', (d: any) => yScale(d.numberSales))
            .attr('dy', -6)
            .text((d: any) => d.numberSales)
            .attr("text-anchor", "middle");

        svg
            .select('.x-axis')
            .append('text')
            .attr('x', (width - margin.left - margin.right) / 2)
            .attr('y', 60)
            .attr('fill', '#000')
            .style('font-size', '20px')
            .style('text-anchor', 'middle')
            .text('Date');

        svg
            .select('.y-axis')
            .append('text')
            .attr('x', 0)
            .attr('y', 0)
            .attr('transform', `translate(-50, ${(height - margin.top - margin.bottom )/ 2}) rotate(-90)`)
            .attr('fill', '#000')
            .style('font-size', '20px')
            .style('text-anchor', 'middle')
            .text('Nombre de ventes');

    }, []);

    return (
        <svg ref={svgRef} width={width} height={height} />
    );
};

export default function BarChart(props: any) {

    return (
        <div>
            <h1>Affichage des données par un diagramme à barre</h1>
            <div style={{ marginLeft: 10, }}>
                <Bar data={props.data} width={props.width} height={props.height} />
            </div>
        </div>
    )
}