import React, { useEffect, useState } from "react";
import Footer from "./PageComponents/footer";
import Header from "./PageComponents/header";
import TabsContainer from "./Tabs/container";
import TimeSeries from "./Graphs/timeserie";
import BarChart from "./Graphs/barchart";
import DonutChart from "./Graphs/donutchart";
import Head from "next/head";

export default function Graphs() {

    const [numberOfSalesData, setNumberOfSalesData] = useState<any[]>([]);

    const fetchNumberOfSalesData = async () => {
        const response = await fetch(`https://localhost/number_sales_by_date/month/2021-01-12/2021-12-31?page=1`, {
            method: 'GET',
            headers: {
                'Content-Type': 'application/json',
            },
        });

        if (!response.ok) return console.log('Data not found !');
        const data = await response.json();
        const res = data['hydra:member'].map((v: any) => {
            const split = v.date.split('T')[0];
            return {
                date: split.substring(0, split.lastIndexOf('-')),
                numberSales: v.numberSales
            }
        });
        setNumberOfSalesData(res);
    }

    useEffect(() => {
        fetchNumberOfSalesData();
    }, [numberOfSalesData]);

    // Component in each tab
    const tabs = [
        <TimeSeries key={0} tabLabel="Série temporelle" width={1000} height={500} />,
        <BarChart key={1} tabLabel="Diagramme à barre" width={1000} height={500} data={numberOfSalesData || []} />,
        <DonutChart key={2} tabLabel="Diagramme circulaire" width={1000} height={500} />
    ];

    return (
        <div>
            <Head>
                <title>Graphiques</title>
            </Head>
            <Header />
            <TabsContainer tabs={tabs} />
            <Footer />
        </div>
    )
};